!*****************************************************************************
!                                                                            *
!  FGFW1.F90                                                                 *
!                                                                            *
!  Demonstrate the basic Fastgraph/Fonts for Windows operations of font      *
!  loading, character display and justification, and font unloading.         *
!                                                                            *
!*****************************************************************************

integer*4 function WinMain (hInstance, hPrevInstance, lpszCmdParam, nCmdShow)
!MS$ATTRIBUTES STDCALL, ALIAS : '_WinMain@16' :: WinMain
use msfwina
use fgwin
use fgfwin

interface
integer*4 function WindowProc (window, message, wParam, lParam)
!MS$ATTRIBUTES STDCALL, ALIAS:'_WindowProc@16' :: WindowProc
integer*4 window, message, wParam, lParam
end function WindowProc
end interface

integer*4 hInstance, hPrevInstance, lpszCmdParam, nCmdShow

character*12      AppName
integer*4         iret
integer*4         window
type (T_MSG)      msg
type (T_WNDCLASS) wndclass

data AppName /'FGFW1'C/

if (hPrevInstance == 0) then
   wndclass%style         = CS_HREDRAW .or. CS_VREDRAW .or. CS_OWNDC
   wndclass%lpfnWndProc   = LOC(WindowProc)
   wndclass%cbClsExtra    = 0
   wndclass%cbWndExtra    = 0
   wndclass%hInstance     = hInstance
   wndclass%hIcon         = LoadIcon(NULL,IDI_APPLICATION)
   wndclass%hCursor       = LoadCursor(NULL,IDC_ARROW)
   wndclass%hbrBackground = NULL
   wndclass%lpszMenuName  = NULL
   wndclass%lpszClassName = LOC(AppName)
   iret = RegisterClass(wndclass)
   lpszCmdParam = lpszCmdParam
end if

window = CreateWindow(    &
   AppName,               &  ! window class name
   'Example FGFW1'C,      &  ! window caption
   WS_OVERLAPPEDWINDOW,   &  ! window style
   CW_USEDEFAULT,         &  ! initial x position
   CW_USEDEFAULT,         &  ! initial y position
   CW_USEDEFAULT,         &  ! initial x size
   CW_USEDEFAULT,         &  ! initial y size
   NULL,                  &  ! parent window handle
   NULL,                  &  ! window menu handle
   hInstance,             &  ! program instance handle
   NULL)                     ! creation parameters

iret = ShowWindow(window,nCmdShow)
iret = UpdateWindow(window)

do while (GetMessage(msg,NULL,0,0))
   iret = TranslateMessage(msg)
   iret = DispatchMessage(msg)
end do

WinMain = msg%wParam
return
end

!*****************************************************************************
!                                                                            *
!  WindowProc                                                                *
!                                                                            *
!  Window procedure to handle messages sent to the window.                   *
!                                                                            *
!*****************************************************************************

integer*4 function WindowProc (window, message, wParam, lParam)
!MS$ATTRIBUTES STDCALL, ALIAS:'_WindowProc@16' :: WindowProc
use msfwina
use fgwin
use fgfwin
integer*4 window, message, wParam, lParam

type (T_PAINTSTRUCT) ps
integer*4 cxClient, cyClient
integer*4 hdc, hpal, hvb
integer*4 maxx, maxy, midx, midy
integer*4 iret

save cxClient, cyClient, hdc, hpal, hvb

WindowProc = 0

select case (message)
   case (WM_CREATE)
      hdc = GetDC(window)
      call fg_setdc(hdc)
      hpal = fg_defpal()
      call fg_realize(hpal)

      call fg_vbinit
      hvb = fg_vballoc(640,480)
      iret = fg_vbopen(hvb)
      call fg_vbcolors

      if (fgf_load('AUSTIN36.FGF'C) == 0) then
         iret = MessageBox(window,'Unable to load font file.'C,'Error'C, &
                           MB_ICONSTOP.or.MB_OK)
         iret = DestroyWindow(window)
         return
      end if

      maxx = fg_getmaxx()
      maxy = fg_getmaxy()
      midx = maxx / 2
      midy = maxy / 2

      call fg_setcolor(255)
      call fg_fillpage

      call fg_setcolor(19)
      call fg_move(0,0)
      call fgf_justify(-1,1)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(midx,0)
      call fgf_justify(0,1)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(maxx,0)
      call fgf_justify(1,1)
      call fgf_print('FG/Fonts'C,8)

      call fg_move(0,midy)
      call fgf_justify(-1,0)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(midx,midy)
      call fgf_justify(0,0)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(maxx,midy)
      call fgf_justify(1,0)
      call fgf_print('FG/Fonts'C,8)

      call fg_move(0,maxy)
      call fgf_justify(-1,-1)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(midx,maxy)
      call fgf_justify(0,-1)
      call fgf_print('FG/Fonts'C,8)
      call fg_move(maxx,maxy)
      call fgf_justify(1,-1)
      call fgf_print('FG/Fonts'C,8)
      return

   case (WM_PAINT)
      iret = BeginPaint(window,ps)
      call fg_vbscale(0,fg_getmaxx(),0,fg_getmaxy(),0,cxClient-1,0,cyClient-1)
      iret = EndPaint(window,ps)
      return

   case (WM_SETFOCUS)
      call fg_realize(hpal)
      iret = InvalidateRect(window,NULL_RECT,.TRUE.)
      return

   case (WM_SIZE)
      cxClient = LOWORD(lParam)
      cyClient = HIWORD(lParam)
      return

   case (WM_DESTROY)
      call fgf_unload(-1)
      call fg_vbclose
      call fg_vbfree(hvb)
      call fg_vbfin
      iret = DeleteObject(hpal)
      iret = ReleaseDC(window,hdc)
      call PostQuitMessage(0)
      return
end select

WindowProc = DefWindowProc(window,message,wParam,lParam)
return
end
