{*****************************************************************************
*                                                                            *
*  FGFW1.DPR                                                                 *
*  FGFW1U.PAS                                                                *
*                                                                            *
*  Demonstrate the basic Fastgraph/Fonts for Windows operations of font      *
*  loading, character display and justification, and font unloading.         *
*                                                                            *
*****************************************************************************}

unit Fgfw1u;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, FGWin, FGFWin;

type
  TForm1 = class(TForm)
    procedure AppOnActivate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
var
  cxClient, cyClient : integer;
  dc   : hDC;
  hpal : hPalette;
  hvb  : integer;

procedure TForm1.AppOnActivate(Sender: TObject);
begin
  fg_realize(hpal);
  Invalidate;
end;

procedure TForm1.FormActivate(Sender: TObject);
begin
  fg_realize(hpal);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  maxx, maxy, midx, midy : integer;

begin
  dc := GetDC(Form1.Handle);
  fg_setdc(dc);
  hpal := fg_defpal;
  fg_realize(hpal);

  fg_vbinit;
  hvb := fg_vballoc(640,480);
  fg_vbopen(hvb);
  fg_vbcolors;

  if fgf_load('AUSTIN36.FGF'+chr(0)) = 0 then
  begin
    MessageDlg('Unable to load font file.',mtError,[mbOK],0);
    Application.Terminate;
    Exit;
  end;

  maxx := fg_getmaxx;
  maxy := fg_getmaxy;
  midx := maxx div 2;
  midy := maxy div 2;

  fg_setcolor(255);
  fg_fillpage;

  fg_setcolor(19);
  fg_move(0,0);
  fgf_justify(-1,1);
  fgf_print('FG/Fonts',8);
  fg_move(midx,0);
  fgf_justify(0,1);
  fgf_print('FG/Fonts',8);
  fg_move(maxx,0);
  fgf_justify(1,1);
  fgf_print('FG/Fonts',8);

  fg_move(0,midy);
  fgf_justify(-1,0);
  fgf_print('FG/Fonts',8);
  fg_move(midx,midy);
  fgf_justify(0,0);
  fgf_print('FG/Fonts',8);
  fg_move(maxx,midy);
  fgf_justify(1,0);
  fgf_print('FG/Fonts',8);

  fg_move(0,maxy);
  fgf_justify(-1,-1);
  fgf_print('FG/Fonts',8);
  fg_move(midx,maxy);
  fgf_justify(0,-1);
  fgf_print('FG/Fonts',8);
  fg_move(maxx,maxy);
  fgf_justify(1,-1);
  fgf_print('FG/Fonts',8);

  Application.OnActivate := AppOnActivate;
end;

procedure TForm1.FormPaint(Sender: TObject);
begin
  fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
end;

procedure TForm1.FormResize(Sender: TObject);
begin
  cxClient := ClientWidth;
  cyClient := ClientHeight;
  Invalidate;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  fgf_unload(-1);
  fg_vbclose;
  fg_vbfree(hvb);
  fg_vbfin;
  DeleteObject(hpal);
  ReleaseDC(Form1.Handle,dc);
end;

end.
