{*****************************************************************************
*                                                                            *
*  FGFW4.DPR                                                                 *
*  FGFW4U.PAS                                                                *
*                                                                            *
*  Demonstrate manual font loading.                                          *
*                                                                            *
*****************************************************************************}

unit Fgfw4u;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, FGWin, FGFWin;

type
  TForm1 = class(TForm)
    procedure AppOnActivate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
const
  FONTSIZE = 8258;

var
  cxClient, cyClient : integer;
  dc   : hDC;
  hpal : hPalette;
  hvb  : integer;
  font_array : array [1..FONTSIZE] of byte;

procedure TForm1.AppOnActivate(Sender: TObject);
begin
  fg_realize(hpal);
  Invalidate;
end;

procedure TForm1.FormActivate(Sender: TObject);
begin
  fg_realize(hpal);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  stream : file;

begin
  dc := GetDC(Form1.Handle);
  fg_setdc(dc);
  hpal := fg_defpal;
  fg_realize(hpal);

  fg_vbinit;
  hvb := fg_vballoc(640,480);
  fg_vbopen(hvb);
  fg_vbcolors;

  {$I-}
  AssignFile(stream,'MODERN28.FGF');
  Reset(stream,1);
  if IOResult <> 0 then
  begin
    MessageDlg('Unable to load font file.',mtError,[mbOK],0);
    Application.Terminate;
    Exit;
  end;
  BlockRead(stream,font_array,FONTSIZE);
  CloseFile(stream);
  {$I+}
  fgf_define(font_array);

  fg_setcolor(255);
  fg_fillpage;

  fg_setcolor(19);
  fg_move(fg_getmaxx div 2,fg_getmaxy div 2);
  fgf_justify(0,0);
  fgf_print('FG/Fonts',8);

  Application.OnActivate := AppOnActivate;
end;

procedure TForm1.FormPaint(Sender: TObject);
begin
  fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
end;

procedure TForm1.FormResize(Sender: TObject);
begin
  cxClient := ClientWidth;
  cyClient := ClientHeight;
  Invalidate;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  fg_vbclose;
  fg_vbfree(hvb);
  fg_vbfin;
  DeleteObject(hpal);
  ReleaseDC(Form1.Handle,dc);
end;

end.
